---
title: "Example"
linkTitle: "Example"
weight: 4
description: >
  Example of a package
---

## Registers

### First example
An 8-bit register

### Second example
A 16-bit register

### Third example
A 32-bit register

### Fourth example
A dummy register that has no data

## License
Licensed under [Apache-2.0](https://spdx.org/licenses/Apache-2.0.html#licenseText).

_Example version 0.1.0_

_Based on Cyanobyte spec version 0.1.0_

_Generated from Cyanobyte Codegen version 0.1.0_